@@ -30,7 +30,6 @@
 #include "kpMainWindowPrivate.h"
 
 #include <QActionGroup>
-#include <QList>
 
 #include <KActionCollection>
 #include <KSharedConfig>
@@ -43,7 +42,6 @@
 #include "document/kpDocument.h"
 #include "layers/selections/image/kpImageSelectionTransparency.h"
 #include "tools/kpTool.h"
-#include "tools/kpToolAction.h"
 #include "tools/flow/kpToolBrush.h"
 #include "tools/flow/kpToolColorEraser.h"
 #include "tools/kpToolColorPicker.h"
@@ -242,7 +240,7 @@ void kpMainWindow::enableToolsDocumentActions (bool enable)
 
     for (auto *tool : d->tools)
     {
-      kpToolAction *action = tool->action();
+      KToggleAction *action = tool->action();
       if (!enable && action->isChecked()) {
           action->setChecked(false);
       }
